# genutility

A collection of various Python utilities.

Requires Python 3.6+.
The last version which mostly worked with Python 2.7 was `0.0.59`.
The last version which mostly worked with Python 3.5 was `0.0.65`.
